.. :changelog:

History
-------

0.3.0 (2017-06-28)
~~~~~~~~~~~~~~~~~~

* Create methods to add items to the label
* Give user option to allow the parser to succeed in parsing broken labels

0.2.0 (2015-08-13)
~~~~~~~~~~~~~~~~~~

* Drastically increase test coverage.
* Lots of bug fixes.
* Add Cube and PDS encoders.
* Cleanup README.
* Use pvl specification terminology.
* Added element access by index and slice.

0.1.1 (2015-06-01)
~~~~~~~~~~~~~~~~~~

* Fixed issue with reading Pancam PDS Products.

0.1.0 (2015-05-30)
~~~~~~~~~~~~~~~~~~

* First release on PyPI.
